import { defineComponent, ref, openBlock, createElementBlock, createCommentVNode, createElementVNode, withModifiers, renderSlot, Fragment, renderList, toDisplayString, normalizeStyle } from 'vue';

/******************************************************************************
Copyright (c) Microsoft Corporation.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
PERFORMANCE OF THIS SOFTWARE.
***************************************************************************** */

function __awaiter(thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
}

function __generator(thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g = Object.create((typeof Iterator === "function" ? Iterator : Object).prototype);
    return g.next = verb(0), g["throw"] = verb(1), g["return"] = verb(2), typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (g && (g = 0, op[0] && (_ = 0)), _) try {
            if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [op[0] & 2, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
}

typeof SuppressedError === "function" ? SuppressedError : function (error, suppressed, message) {
    var e = new Error(message);
    return e.name = "SuppressedError", e.error = error, e.suppressed = suppressed, e;
};

var script = defineComponent({
    name: 'FileUploader',
    // 组件属性定义
    props: {
        action: {
            type: String,
            required: true
        },
        multiple: {
            type: Boolean,
            default: false
        },
        accept: {
            type: String,
            default: ''
        },
        maxSize: {
            type: Number,
            default: 0
        },
        maxCount: {
            type: Number,
            default: 0
        },
        headers: {
            type: Object,
            default: function () { return ({}); }
        },
        data: {
            type: Object,
            default: function () { return ({}); }
        },
        autoUpload: {
            type: Boolean,
            default: true
        },
        fileList: {
            type: Array,
            default: function () { return []; }
        }
    },
    // 组件事件定义
    emits: ['update:fileList', 'change', 'success', 'error', 'exceed'],
    setup: function (props, _a) {
        var _this = this;
        var emit = _a.emit, expose = _a.expose;
        // 文件输入框引用
        var fileInput = ref(null);
        // 文件列表状态
        var fileList = ref(props.fileList);
        // 存储待上传的文件
        var pendingFiles = ref(new Map());
        /**
         * 处理点击上传
         * 触发文件选择框
         */
        var handleClick = function () {
            var _a;
            (_a = fileInput.value) === null || _a === void 0 ? void 0 : _a.click();
        };
        /**
         * 处理文件选择
         * 当用户通过文件选择框选择文件时触发
         */
        var handleChange = function (event) {
            var _a;
            var target = event.target;
            if (!((_a = target.files) === null || _a === void 0 ? void 0 : _a.length))
                return;
            var files = Array.from(target.files);
            handleFiles(files);
            target.value = ''; // 重置input，允许选择相同文件
        };
        /**
         * 处理文件拖拽
         * 当用户拖拽文件到上传区域时触发
         */
        var handleDrop = function (event) {
            var _a;
            var files = Array.from(((_a = event.dataTransfer) === null || _a === void 0 ? void 0 : _a.files) || []);
            handleFiles(files);
        };
        /**
         * 处理文件上传
         * 验证文件并添加到上传列表
         */
        var handleFiles = function (files) {
            // 检查文件数量限制
            if (props.maxCount && fileList.value.length + files.length > props.maxCount) {
                emit('exceed', files);
                return;
            }
            files.forEach(function (file) {
                // 检查文件大小限制
                if (props.maxSize && file.size > props.maxSize) {
                    emit('error', new Error('文件大小超出限制'), file);
                    return;
                }
                // 创建上传文件对象
                var uploadFile = {
                    uid: Date.now() + Math.random().toString(36).slice(2),
                    name: file.name,
                    size: file.size,
                    type: file.type,
                    status: 'ready',
                    percentage: 0
                };
                // 添加到文件列表
                fileList.value.push(uploadFile);
                // 存储原始文件对象，用于后续上传
                pendingFiles.value.set(uploadFile.uid, file);
                emit('update:fileList', fileList.value);
                emit('change', { file: uploadFile, fileList: fileList.value });
                // 自动上传
                if (props.autoUpload) {
                    upload(file, uploadFile);
                }
            });
        };
        /**
         * 上传文件到服务器
         * 使用 fetch API 发送文件
         */
        var upload = function (file, uploadFile) { return __awaiter(_this, void 0, void 0, function () {
            var formData, response, result, error_1;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        formData = new FormData();
                        formData.append('file', file);
                        // 添加额外参数
                        Object.entries(props.data).forEach(function (_a) {
                            var key = _a[0], value = _a[1];
                            formData.append(key, value);
                        });
                        uploadFile.status = 'uploading';
                        _a.label = 1;
                    case 1:
                        _a.trys.push([1, 4, , 5]);
                        return [4 /*yield*/, fetch(props.action, {
                                method: 'POST',
                                headers: props.headers,
                                body: formData
                            })];
                    case 2:
                        response = _a.sent();
                        return [4 /*yield*/, response.json()];
                    case 3:
                        result = _a.sent();
                        if (response.ok) {
                            uploadFile.status = 'success';
                            uploadFile.response = result;
                            uploadFile.url = result.url;
                            emit('success', uploadFile, fileList.value);
                        }
                        else {
                            throw new Error(result.message || '上传失败');
                        }
                        return [3 /*break*/, 5];
                    case 4:
                        error_1 = _a.sent();
                        uploadFile.status = 'error';
                        uploadFile.error = error_1;
                        emit('error', error_1, uploadFile);
                        return [3 /*break*/, 5];
                    case 5:
                        emit('update:fileList', fileList.value);
                        return [2 /*return*/];
                }
            });
        }); };
        /**
         * 从列表中移除文件
         */
        var removeFile = function (file) {
            var index = fileList.value.indexOf(file);
            if (index > -1) {
                fileList.value.splice(index, 1);
                emit('update:fileList', fileList.value);
            }
        };
        /**
         * 格式化文件大小
         * 将字节数转换为人类可读的格式
         */
        var formatSize = function (bytes) {
            if (bytes === 0)
                return '0 B';
            var k = 1024;
            var sizes = ['B', 'KB', 'MB', 'GB', 'TB'];
            var i = Math.floor(Math.log(bytes) / Math.log(k));
            return "".concat((bytes / Math.pow(k, i)).toFixed(2), " ").concat(sizes[i]);
        };
        /**
         * 手动上传文件
         * 上传所有状态为 ready 的文件
         */
        var submit = function () {
            fileList.value.forEach(function (uploadFile) {
                if (uploadFile.status === 'ready') {
                    var file = pendingFiles.value.get(uploadFile.uid);
                    if (file) {
                        upload(file, uploadFile);
                    }
                }
            });
        };
        // 暴露方法给父组件
        expose({
            submit: submit,
            handleClick: handleClick,
            fileInput: fileInput
        });
        return {
            fileInput: fileInput,
            fileList: fileList,
            handleClick: handleClick,
            handleChange: handleChange,
            handleDrop: handleDrop,
            handleDragover: function () { },
            handleDragleave: function () { },
            removeFile: removeFile,
            formatSize: formatSize,
            submit: submit
        };
    }
});

const _hoisted_1 = { class: "vue-file-uploader" };
const _hoisted_2 = {
  key: 0,
  class: "uploader-list"
};
const _hoisted_3 = { class: "file-info" };
const _hoisted_4 = { class: "file-name" };
const _hoisted_5 = { class: "file-size" };
const _hoisted_6 = { class: "file-status" };
const _hoisted_7 = {
  key: 1,
  class: "success"
};
const _hoisted_8 = {
  key: 2,
  class: "error"
};
const _hoisted_9 = ["onClick"];
const _hoisted_10 = ["accept", "multiple"];

function render(_ctx, _cache, $props, $setup, $data, $options) {
  return (openBlock(), createElementBlock("div", _hoisted_1, [
    createCommentVNode(" 上传触发区域：点击或拖拽上传 "),
    createElementVNode("div", {
      class: "uploader-trigger",
      onDrop: _cache[1] || (_cache[1] = withModifiers((...args) => (_ctx.handleDrop && _ctx.handleDrop(...args)), ["prevent"])),
      onDragover: _cache[2] || (_cache[2] = withModifiers((...args) => (_ctx.handleDragover && _ctx.handleDragover(...args)), ["prevent"])),
      onDragleave: _cache[3] || (_cache[3] = withModifiers((...args) => (_ctx.handleDragleave && _ctx.handleDragleave(...args)), ["prevent"]))
    }, [
      createCommentVNode(" 默认上传区域，可通过插槽自定义 "),
      renderSlot(_ctx.$slots, "default", {}, () => [
        createElementVNode("div", {
          class: "uploader-placeholder",
          onClick: _cache[0] || (_cache[0] = (...args) => (_ctx.handleClick && _ctx.handleClick(...args)))
        }, _cache[5] || (_cache[5] = [
          createElementVNode("i", { class: "uploader-icon" }, "+", -1 /* HOISTED */),
          createElementVNode("div", { class: "uploader-text" }, "点击或拖拽文件上传", -1 /* HOISTED */)
        ]))
      ])
    ], 32 /* NEED_HYDRATION */),
    createCommentVNode(" 文件列表展示区域 "),
    (_ctx.fileList.length)
      ? (openBlock(), createElementBlock("div", _hoisted_2, [
          (openBlock(true), createElementBlock(Fragment, null, renderList(_ctx.fileList, (file) => {
            return (openBlock(), createElementBlock("div", {
              key: file.uid,
              class: "uploader-file"
            }, [
              createCommentVNode(" 文件信息展示 "),
              createElementVNode("div", _hoisted_3, [
                createElementVNode("span", _hoisted_4, toDisplayString(file.name), 1 /* TEXT */),
                createElementVNode("span", _hoisted_5, toDisplayString(_ctx.formatSize(file.size)), 1 /* TEXT */)
              ]),
              createCommentVNode(" 文件状态展示 "),
              createElementVNode("div", _hoisted_6, [
                createCommentVNode(" 上传进度条 "),
                (file.status === 'uploading')
                  ? (openBlock(), createElementBlock("div", {
                      key: 0,
                      class: "progress-bar",
                      style: normalizeStyle({ width: `${file.percentage}%` })
                    }, null, 4 /* STYLE */))
                  : createCommentVNode("v-if", true),
                createCommentVNode(" 上传成功/失败图标 "),
                (file.status === 'success')
                  ? (openBlock(), createElementBlock("span", _hoisted_7, "✓"))
                  : createCommentVNode("v-if", true),
                (file.status === 'error')
                  ? (openBlock(), createElementBlock("span", _hoisted_8, "×"))
                  : createCommentVNode("v-if", true)
              ]),
              createCommentVNode(" 删除按钮 "),
              createElementVNode("button", {
                class: "delete-btn",
                onClick: $event => (_ctx.removeFile(file))
              }, "删除", 8 /* PROPS */, _hoisted_9)
            ]))
          }), 128 /* KEYED_FRAGMENT */))
        ]))
      : createCommentVNode("v-if", true),
    createCommentVNode(" 隐藏的文件输入框 "),
    createElementVNode("input", {
      ref: "fileInput",
      type: "file",
      accept: _ctx.accept,
      multiple: _ctx.multiple,
      style: {"display":"none"},
      onChange: _cache[4] || (_cache[4] = (...args) => (_ctx.handleChange && _ctx.handleChange(...args)))
    }, null, 40 /* PROPS, NEED_HYDRATION */, _hoisted_10)
  ]))
}

script.render = render;
script.__scopeId = "data-v-39ca3b3a";
script.__file = "src/components/FileUploader.vue";

/**
 * Vue File Uploader 组件入口文件
 * 支持 Vue 2.x 和 Vue 3.x
 */
/**
 * Vue 插件安装函数
 * 用于全局注册组件
 * @param app Vue 应用实例
 */
function install(app) {
    app.component('FileUploader', script);
}
// 导出 Vue 插件
var index = {
    install: install,
};

export { script as FileUploader, index as default, install };
//# sourceMappingURL=vue-file-uploader.esm.js.map
