/**
 * Rollup 配置文件
 * 用于构建支持 ESM 和 CommonJS 的 Vue 组件库
 */

import typescript from 'rollup-plugin-typescript2';
import vue from 'rollup-plugin-vue';
import postcss from 'rollup-plugin-postcss';
import pkg from './package.json';

export default {
  // 入口文件
  input: 'src/index.ts',
  
  // 输出配置
  output: [
    {
      // CommonJS 格式输出
      file: pkg.main,
      format: 'cjs',
      exports: 'named',
      sourcemap: true
    },
    {
      // ES Module 格式输出
      file: pkg.module,
      format: 'es',
      exports: 'named',
      sourcemap: true
    }
  ],
  
  // 外部依赖，不会被打包进最终文件
  external: [
    ...Object.keys(pkg.peerDependencies || {}),
  ],
  
  // 插件配置
  plugins: [
    // Vue 单文件组件编译插件
    vue({
      target: 'browser', // 目标环境
      css: false,        // 禁用 vue 插件的 CSS 处理，交给 postcss 插件处理
      exposeFilename: false,
    }),
    
    // TypeScript 编译插件
    typescript({
      typescript: require('typescript'),
      useTsconfigDeclarationDir: true, // 使用 tsconfig 中配置的声明文件输出目录
    }),
    
    // PostCSS 处理插件
    postcss({
      extract: 'vue-file-uploader.css',    // 提取 CSS 到单独文件
      modules: false,   // 不使用 CSS Modules
      minimize: true,   // 压缩 CSS
      sourceMap: true
    })
  ]
}; 